package Acme::CPANAuthors::CPANTS::FiveOrMore;

#
# THIS IS A GENERATED FILE. DO NOT UPDATE DIRECTLY.
#

use 5.006;
use strict;
use warnings;
no  warnings 'syntax';

our $VERSION = '2010072801';

use Acme::CPANAuthors::Register (
    q <AALLAN> => q <Alasdair Allan>,
    q <AAR> => q <Alessandro Ranellucci>,
    q <AAYARS> => q <Alex Ayars>,
    q <ABEL> => q <Anton Belousov>,
    q <ABELTJE> => q <Abe Timmerman>,
    q <ABERGMAN> => q <Artur Bergman>,
    q <ABH> => q <Ask Bjoern Hansen>,
    q <ABIGAIL> => q <Abigail>,
    q <ABW> => q <Andy Wardley>,
    q <ACALPINI> => q <Aldo Calpini>,
    q <ACCARDO> => q <Michael Accardo>,
    q <ADAMK> => q <Adam Kennedy>,
    q <ADDI> => q <Arnar Mar Hrafnkelsson>,
    q <ADRIANWIT> => q <Adrian Witas>,
    q <AGENT> => q <agentzh>,
    q <AGOLOMSH> => q <Alexander Golomshtok>,
    q <AGRUNDMA> => q <Andy Grundman>,
    q <AGUL> => q <Ashish Gulhati>,
    q <AHICOX> => q <Andrew Hicox>,
    q <AJGB> => q <Alex J. G. Burzynski>,
    q <AJGOUGH> => q <Alex Gough>,
    q <AJOLMA> => q <Ari Jolma>,
    q <AKSTE> => q <Alan K. Stebbens>,
    q <ALEC> => q <Alec Chen>,
    q <ALEXBIO> => q <Alessandro Ghedini>,
    q <ALEXMASS> => q <Alexandre Masselot>,
    q <ALEXMV> => q <Alex Vandiver>,
    q <ALEXP> => q <Alex Pavlovic>,
    q <ALIAN> => q <Alain Barbet>,
    q <ALIZTA> => q <Alistair Francis>,
    q <ALLENDAY> => q <Allen Day>,
    q <AMALTSEV> => q <Andrew Maltsev>,
    q <AMBS> => q <Alberto Manuel Brandao Simoes>,
    q <AMONTERO> => q <Alberto Montero Asenjo>,
    q <AMS> => q <Abhijit Menon-Sen>,
    q <ANDK> => q <Andreas J. Koenig>,
    q <ANDREMAR> => q <Andreas Marienborg>,
    q <ANDREWF> => q <Andrew Ford>,
    q <ANDY> => q <Andrew Shitov>,
    q <ANDYA> => q <Andy Armstrong>,
    q <ANNO> => q <Anno Siegel>,
    q <APLA> => q <Ivan Baktsheev>,
    q <APLEINER> => q <Alex Pleiner>,
    q <APOCAL> => q <Apocalypse>,
    q <AQUMSIEH> => q <Ala Qumsieh>,
    q <AREGGIORI> => q <areggiori>,
    q <ARISTOTLE> => q <Aristotle Pagaltzis>,
    q <ARODLAND> => q <Andrew Rodland>,
    q <ARTICLE> => q <Andrew Green>,
    q <ASAKURA> => q <ASAKURA Takuji>,
    q <ASCHAMP> => q <Andrew Schamp>,
    q <ASCOPE> => q <Aaron Straup Cope>,
    q <ASH> => q <Ash Berlin>,
    q <ASHLEY> => q <Ashley Pond V>,
    q <ASKSH> => q <Ask Solem>,
    q <ASPEER> => q <Andrew Speer>,
    q <ATHOMASON> => q <Adam Thomason>,
    q <AUDREYT> => q <Audrey Tang>,
    q <AUTRIJUS> => q <Audrey Tang>,
    q <AVAR> => q <AEvar Arnfjord Bjarmason>,
    q <AVIF> => q <Avi Finkel>,
    q <AWIN> => q <Ashley Winters>,
    q <AWNCORP> => q <Al Newkirk>,
    q <AWRIGLEY> => q <Ave Wrigley>,
    q <AWWAIID> => q <Brock Wilcox>,
    q <BARBIE> => q <Barbie>,
    q <BBAXTER> => q <Brad Baxter>,
    q <BBB> => q <Rob Brown>,
    q <BBC> => q <BBC (British Broadcasting Corporation)>,
    q <BDFOY> => q <brian d foy>,
    q <BDUGGAN> => q <Brian Duggan>,
    q <BEATNIK> => q <Hendrik Van Belleghem>,
    q <BEAU> => q <Beau E. Cox>,
    q <BENNIE> => q <Phillip Pollard>,
    q <BEPPU> => q <John Beppu>,
    q <BERLE> => q <Anders Nor Berle>,
    q <BHOLZMAN> => q <Benjamin Holzman>,
    q <BIGJ> => q <Janek Schleicher>,
    q <BIGPRESH> => q <David Precious>,
    q <BIKER> => q <Frank Dupont>,
    q <BILLH> => q <William Herrera>,
    q <BINGOS> => q <Chris Williams>,
    q <BINKLEY> => q <B. K. Oxley (binkley)>,
    q <BJOERN> => q <Bjoern Hoehrmann>,
    q <BLBLACK> => q <Brandon L Black>,
    q <BLOM> => q <Menno Blom>,
    q <BLUEFEET> => q <Aran Clary Deltac>,
    q <BMAMES> => q <Brian M. Ames>,
    q <BOBTFISH> => q <Tomas Doran>,
    q <BOKUTIN> => q <Tomohiro Hosaka>,
    q <BOLAV> => q <Bjorn-Olav Strand>,
    q <BOOK> => q <Philippe Bruhat (BooK)>,
    q <BORISZ> => q <Boris Zentner>,
    q <BOSU> => q <Boris Sukholitko>,
    q <BOWMANBS> => q <Brad Bowman>,
    q <BPOSTLE> => q <Bruno Postle>,
    q <BPOWERS> => q <Brent B. Powers>,
    q <BPRUDENT> => q <Brandon Prudent>,
    q <BRADFITZ> => q <Brad Fitzpatrick>,
    q <BRADMC> => q <Brad McConahay>,
    q <BRENTDAX> => q <Brent Dax>,
    q <BRIAC> => q <Briac Pilpre>,
    q <BRICAS> => q <Brian Cassidy>,
    q <BROQ> => q <Dan Brook>,
    q <BRYCE> => q <Bryce Harrington>,
    q <BTROTT> => q <Benjamin Trott>,
    q <BURAK> => q <Burak Gursoy>,
    q <BZAJAC> => q <Blair Zajac>,
    q <CADE> => q <Vladi Belperchinov-Shabanski>,
    q <CASIANO> => q <Casiano Rodriguez-Leon>,
    q <CBERRY> => q <Craig A. Berry>,
    q <CBOUVI> => q <Cedric Bouvier>,
    q <CCCP> => q <Sivirinov Ivan>,
    q <CCOBB> => q <Chris Cobb>,
    q <CDENT> => q <Chris Dent>,
    q <CDOLAN> => q <Chris Dolan>,
    q <CEESHEK> => q <Cees Hek>,
    q <CFAERBER> => q <Claus Faerber>,
    q <CFEDDE> => q <Chris Fedde>,
    q <CFRANKS> => q <Carl Franks>,
    q <CGILMORE> => q <Christian Gilmore>,
    q <CHANSEN> => q <Christian Hansen>,
    q <CHIBA> => q <Masahiro Chiba>,
    q <CHISEL> => q <Chisel Wright>,
    q <CHOCOLATE> => q <chocolateboy>,
    q <CHORNY> => q <Alexandr Ciornii>,
    q <CHRIS> => q <Chris Ball>,
    q <CHRISJ> => q <Chris Josephes>,
    q <CHRMUE> => q <Christian Mueller>,
    q <CHROMATIC> => q <chromatic>,
    q <CHUNZI> => q <chunzi>,
    q <CJM> => q <Christopher J. Madsen>,
    q <CJONES> => q <Christopher Jones>,
    q <CLACO> => q <Christopher H. Laco>,
    q <CLAESJAC> => q <Claes Jakobsson>,
    q <CLINTDW> => q <Clinton Wong>,
    q <CLIVE> => q <Clive Darke>,
    q <CLKAO> => q <Chia-liang Kao>,
    q <CLOTHO> => q <Clotho Advanced Media>,
    q <CLSUNG> => q <Cheng-Lung Sung>,
    q <CMANLEY> => q <Craig Manley>,
    q <CMUNGALL> => q <Chris Mungall>,
    q <CNANDOR> => q <Chris Nandor>,
    q <COG> => q <Jose' Alves de Castro>,
    q <CONVERTER> => q <David P.C. Wollmann>,
    q <CORDATA> => q <CorData>,
    q <CORION> => q <Max Maischein>,
    q <CORLISS> => q <Arthur Corliss>,
    q <CORNELIUS> => q <Lin You An>,
    q <COSIMO> => q <Cosimo Streppone>,
    q <COSMICNET> => q <Lyle Hopkins>,
    q <CPKOIS> => q <Christopher Kois>,
    q <CRAKRJACK> => q <Tyler MacDonald>,
    q <CREAMYG> => q <Marvin Humphrey>,
    q <CRENZ> => q <Christian Renz>,
    q <CSA> => q <Cyber Sprocket Labs>,
    q <CSJEWELL> => q <Curtis Jewell>,
    q <CTBROWN> => q <Christopher Brown>,
    q <CWEST> => q <Casey West>,
    q <CWINTERS> => q <Chris Winters>,
    q <CYCLES> => q <Oliver Charles>,
    q <DAGOLDEN> => q <David Golden>,
    q <DALEAMON> => q <Dale Amon>,
    q <DAMI> => q <Laurent Dami>,
    q <DAMOG> => q <David Moreno>,
    q <DAMS> => q <Damien Krotkine>,
    q <DANBERR> => q <Daniel P. Berrange>,
    q <DANBOO> => q <Daniel B. Boorstein>,
    q <DANIEL> => q <Dan Sully>,
    q <DANJOU> => q <Nobuo Danjou>,
    q <DANKOGAI> => q <Dan Kogai>,
    q <DANPEDER> => q <Daniel Peder>,
    q <DARNOLD> => q <Dean Arnold>,
    q <DARREN> => q <Darren Chamberlain>,
    q <DAVEBAIRD> => q <David R. Baird>,
    q <DAVECROSS> => q <Dave Cross>,
    q <DAVID> => q <David Caldwell>,
    q <DAVIDNICO> => q <David Nicol>,
    q <DAVIDP> => q <David Peters>,
    q <DAVIDRW> => q <David Westbrook>,
    q <DBRIAN> => q <Danny Brian>,
    q <DBROBINS> => q <David Robins>,
    q <DCANTRELL> => q <David Cantrell>,
    q <DCARDWELL> => q <Dave Cardwell>,
    q <DCHRIS> => q <David A. Christensen>,
    q <DCOLLINS> => q <Dan Collins>,
    q <DCONWAY> => q <Damian Conway>,
    q <DCOPPIT> => q <David Coppit>,
    q <DDICK> => q <David Dick>,
    q <DDUMONT> => q <Dominique Dumont>,
    q <DESPAIR> => q <Walery Studennikov>,
    q <DEXTER> => q <Piotr Roszatycki>,
    q <DGL> => q <David Leadbeater>,
    q <DHORNE> => q <Dan Horne>,
    q <DHUDES> => q <Dana Hudes>,
    q <DIBERRI> => q <David Iberri>,
    q <DIZ> => q <Mike Eldridge>,
    q <DJBERG> => q <Daniel Berger>,
    q <DJERIUS> => q <Diab Jerius>,
    q <DLAND> => q <David Landgren>,
    q <DLUX> => q <Szabo, Balazs>,
    q <DMAKI> => q <Daisuke Maki>,
    q <DMCBRIDE> => q <Darin McBride>,
    q <DMUEY> => q <Daniel Muey>,
    q <DODGER> => q <Sean Cannon>,
    q <DOLMEN> => q <Olivier 'dolmen' Mengue>,
    q <DOM> => q <Dominic Hargreaves>,
    q <DOMIZIO> => q <Domizio Demichelis>,
    q <DOMM> => q <Thomas Klausner>,
    q <DONEILL> => q <David O'Neill>,
    q <DONGXU> => q <Dongxu Ma>,
    q <DOOM> => q <Joseph Brenner>,
    q <DORIAN> => q <Dorian Taylor>,
    q <DOUGDUDE> => q <Douglas Christopher Wilson>,
    q <DOUGM> => q <Doug MacEachern>,
    q <DOWENS> => q <Don Owens>,
    q <DOY> => q <Jesse Luehrs>,
    q <DPAVLIN> => q <Dobrica Pavlinusic>,
    q <DPCHRIST> => q <David Paul Christensen>,
    q <DPRICE> => q <Derek Price>,
    q <DRAEGTUN> => q <Barry Walsh>,
    q <DRBEAN> => q <Dr Bean>,
    q <DROLSKY> => q <Dave Rolsky>,
    q <DRRHO> => q <Robert Barta>,
    q <DRTECH> => q <Clinton Gormley>,
    q <DRUOSO> => q <Daniel Ruoso>,
    q <DSB> => q <David Boyce>,
    q <DSTAAL> => q <Daniel T. Staal>,
    q <DSTH> => q <Daniel S. T. Hughes>,
    q <DSUGAL> => q <Dan Sugalski>,
    q <DUNCAND> => q <Darren Duncan>,
    q <DWHEELER> => q <David E. Wheeler>,
    q <DWILSON> => q <Dean Wilson>,
    q <DWINTERS> => q <David Winters>,
    q <DYACOB> => q <Daniel Yacob>,
    q <DYLAN> => q <Dylan Doxey>,
    q <EALLENIII> => q <Edward J. Allen III>,
    q <EARL> => q <Earl Cahill>,
    q <EBOHLMAN> => q <Eric Bohlman>,
    q <EBRUNI> => q <Bruni Emiliano>,
    q <ECALDER> => q <Erick Calder>,
    q <ECARROLL> => q <Evan Carroll>,
    q <EESTABROO> => q <Eric Estabrooks>,
    q <EGERMAN> => q <eric GERMAN>,
    q <EHOOD> => q <Earl Hood>,
    q <EIDOLON> => q <to be removed. see /~jhthorsen>,
    q <EKAWAS> => q <Edward Kawas>,
    q <ELACOUR> => q <Emmanuel Lacour>,
    q <ELIZABETH> => q <Elizabeth Mattijsen>,
    q <ELLIOTJS> => q <Elliot Shank>,
    q <ELMEX> => q <Robin Redeker>,
    q <ENRYS> => q <Enrico Sorcinelli>,
    q <ERWAN> => q <Erwan Lemonnier>,
    q <ESSKAR> => q <Sascha Kiefer>,
    q <ESUMMERS> => q <Ed Summers>,
    q <EVDB> => q <Edmund von der Burg>,
    q <EVO> => q <Matthew Simon Cavalletto>,
    q <EWATERS> => q <Eric Waters>,
    q <EWILHELM> => q <Eric Wilhelm>,
    q <EXODIST> => q <Chad Granum>,
    q <FABPOT> => q <Fabien Potencier>,
    q <FALCONE> => q <Kevin Falcone>,
    q <FAYLAND> => q <Fayland Lin>,
    q <FDALY> => q <Fergal Daly>,
    q <FDULAU> => q <DULAUNOY Fabrice>,
    q <FERNANDES> => q <Rodrigo Panchiniak Fernandes>,
    q <FERREIRA> => q <Adriano Ferreira>,
    q <FGLOCK> => q <Flavio Soibelmann Glock>,
    q <FLORA> => q <Florian Ragwitz>,
    q <FLORIAN> => q <Florian Helmberger>,
    q <FLUFFY> => q <Martyn J. Pearce>,
    q <FMERGES> => q <Florian Merges>,
    q <FOOLFISH> => q <Qian Yu /Qian Yu>,
    q <FOTANGO> => q <Fotango Ltd>,
    q <FRAJULAC> => q <Francis J. Lacoste>,
    q <FRANCKC> => q <Franck Cuny>,
    q <FREQUENCY> => q <Jonathan Yu (custodial account, see JAWNSY)>,
    q <FREW> => q <Arthur Axel 'fREW' Schmidt>,
    q <FRIEDO> => q <Mike Friedman>,
    q <FRODWITH> => q <Paul Driver>,
    q <FUJIWARA> => q <FUJIWARA Shunichiro>,
    q <GAAL> => q <Gaal Yahas>,
    q <GAAS> => q <Gisle Aas>,
    q <GAFFER> => q <George A. Fitch III>,
    q <GAISSMAI> => q <Karl Gaissmaier>,
    q <GAM> => q <G. Allen Morris III>,
    q <GARU> => q <Breno G. de Oliveira>,
    q <GAVINC> => q <Gavin Carr>,
    q <GBARR> => q <Graham Barr>,
    q <GBROCK> => q <Gavin Brock>,
    q <GBROWN> => q <Gavin Brown>,
    q <GENE> => q <Gene Boggs>,
    q <GEOFF> => q <Geoffrey Young>,
    q <GEOTIGER> => q <Geo Tiger>,
    q <GFUJI> => q <Goro Fuji>,
    q <GIFF> => q <Scott Gifford>,
    q <GLENNWOOD> => q <Glenn Wood>,
    q <GMCCAR> => q <Greg McCarroll>,
    q <GMPASSOS> => q <Graciliano Monteiro Passos>,
    q <GNG> => q <Greg George>,
    q <GOMOR> => q <Patrice Auffret>,
    q <GOSHA> => q <Okunev Igor>,
    q <GOSSAMER> => q <Ricky Buchanan>,
    q <GOZER> => q <Philippe M. Chiasson>,
    q <GPHAT> => q <Cory G Watson>,
    q <GRAF> => q <Bernhard Graf>,
    q <GRANTM> => q <Grant McLean>,
    q <GRAY> => q <gray>,
    q <GREGFAST> => q <Greg Fast>,
    q <GREGOR> => q <Gregor N. Purdy, Sr.>,
    q <GRICHTER> => q <Gerald Richter>,
    q <GRODITI> => q <Guillermo Roditi>,
    q <GROMMEL> => q <Geoffrey Rommel>,
    q <GROUSSE> => q <Guillaume Rousse>,
    q <GSLIN> => q <Gea-Suan Lin>,
    q <GSLONDON> => q <Greg London>,
    q <GTERMARS> => q <Graham TerMarsch>,
    q <GUGOD> => q <Liu Kang Min>,
    q <GUGU> => q <Andrey Kostenko>,
    q <GUIDO> => q <Guido Flohr>,
    q <GUIMARD> => q <Xavier Guimard>,
    q <GWADEJ> => q <G. Wade Johnson>,
    q <GWILLIAMS> => q <Gregory Todd Williams>,
    q <GWYN> => q <Philip Gwyn>,
    q <HACHI> => q <Jonathan Steinert>,
    q <HAGGAI> => q <Alan Haggai Alavi>,
    q <HANENKAMP> => q <Andrew Sterling Hanenkamp>,
    q <HANK> => q <Bill Moseley>,
    q <HARDAKER> => q <Wes Hardaker>,
    q <HAVI> => q <Gernot Havranek>,
    q <HCCHIEN> => q <Hsin-Chan Chien>,
    q <HDAICHI> => q <daichi hiroki>,
    q <HDIAS> => q <Henrique M. Ribeiro Dias>,
    q <HDM> => q <Dominic Mitchell>,
    q <HDP> => q <Hans Dieter Pearcey>,
    q <HESCO> => q <Hugh Esco>,
    q <HIDE> => q <Hideo Kimura>,
    q <HINRIK> => q <Hinrik Orn Sigurdsson>,
    q <HIO> => q <YAMASHINA Hio>,
    q <HIROSE> => q <HIROSE Masaaki>,
    q <HMBRAND> => q <H.Merijn Brand>,
    q <HOLLY> => q <Akira Horimoto>,
    q <HOLMLUND> => q <Daniel Holmlund>,
    q <HOLOWAY> => q <Adam Jacob>,
    q <HORIUCHI> => q <Yasuhiro Horiuchi>,
    q <IAMCAL> => q <Cal Henderson>,
    q <IAN> => q <Ian Langworth>,
    q <ICHI> => q <Takuya Ichikawa>,
    q <IDERRICK> => q <Olivier Schwander>,
    q <IDOPEREL> => q <Ido Perlmuter>,
    q <IJLIAO> => q <Ying-Chieh Liao>,
    q <IKEBE> => q <IKEBE Tomohiro>,
    q <IKLUFT> => q <Ian Kluft>,
    q <ILYAZ> => q <Ilya Zakharevich>,
    q <INFINOID> => q <Mark Glines>,
    q <INGY> => q <Ingy dot Net>,
    q <IOANNIS> => q <Ioannis Tambouras>,
    q <ISHIGAKI> => q <Kenichi Ishigaki>,
    q <ISTERIN> => q <Ilya Sterin>,
    q <ITUB> => q <Ivan Tubert-Brohman>,
    q <IVAN> => q <Ivan Kohler>,
    q <IVANWILLS> => q <Ivan Wills>,
    q <IVORW> => q <Ivor Williams>,
    q <IWADE> => q <Iain Wade>,
    q <IWOODHEAD> => q <Ira Joseph Woodhead>,
    q <IX> => q <Brian Moseley>,
    q <IZUT> => q <Igor Sutton>,
    q <JABRA> => q <Joshua 'Jabra' Abraham>,
    q <JACKS> => q <Jack Shirazi>,
    q <JAK> => q <John A. Kunze>,
    q <JALDHAR> => q <Jaldhar H. Vyas>,
    q <JANPAZ> => q <Jan Pazdziora>,
    q <JARW> => q <John A.R. Williams>,
    q <JASONK> => q <Jason Kohles>,
    q <JASONS> => q <Jason E. Stewart>,
    q <JAW> => q <Jeff Weisberg>,
    q <JBISBEE> => q <Jeff Bisbee>,
    q <JBRIGGS> => q <James Briggs>,
    q <JBRYAN> => q <Josiah Bryan>,
    q <JBUHACOFF> => q <Jonathan Buhacoff>,
    q <JCDUQUE> => q <Julius C. Duque>,
    q <JCHIN> => q <Jonathan Chin>,
    q <JCMULLER> => q <Juan C. Muller>,
    q <JDB> => q <Jan Dubois>,
    q <JDHEDDEN> => q <Jerry D. Hedden>,
    q <JDIEPEN> => q <Joost Diepenmaat>,
    q <JDPORTER> => q <John Douglas Porter>,
    q <JDUNCAN> => q <James A. Duncan>,
    q <JEF> => q <Jeff Finucane>,
    q <JEFFA> => q <Jeffrey Hayes Anderson>,
    q <JENDA> => q <Jan Krynicky>,
    q <JEREMIAH> => q <Jeremiah Foster>,
    q <JESSE> => q <Jesse Vincent>,
    q <JESUS> => q <Theo Schlossnagle>,
    q <JETEVE> => q <Jerome Eteve>,
    q <JETTERO> => q <Paul Miller>,
    q <JFENAL> => q <Jerome Fenal>,
    q <JFITZ> => q <James FitzGibbon>,
    q <JFREEMAN> => q <Dr. James Freeman>,
    q <JGLICK> => q <Jesse N. Glick>,
    q <JGOFF> => q <Jeff Goff>,
    q <JHI> => q <Jarkko Hietaniemi>,
    q <JHIVER> => q <Jean-Michel Hiver>,
    q <JHOBLITT> => q <Joshua Hoblitt>,
    q <JHTHORSEN> => q <Jan Henning Thorsen>,
    q <JIRO> => q <Jiro Nishiguchi>,
    q <JJNAPIORK> => q <John Napiorkowski>,
    q <JJORE> => q <Joshua ben Jore>,
    q <JJSCHUTZ> => q <Jon Schutz>,
    q <JKEENAN> => q <James E Keenan>,
    q <JKRAMER> => q <Jonas Kramer>,
    q <JKUTEJ> => q <Jozef Kutej>,
    q <JLMARTIN> => q <Jose Luis Martinez Torres>,
    q <JMATES> => q <Jeremy Mates>,
    q <JMAY> => q <Jason W. May>,
    q <JMCADA> => q <Joshua McAdams>,
    q <JMCNAMARA> => q <John McNamara>,
    q <JMEHNLE> => q <Julian Mehnle>,
    q <JMERELO> => q <J. J. Merelo Guervos>,
    q <JMMILLS> => q <Jason M. Mills>,
    q <JNW> => q <Juergen Weigert>,
    q <JOHANL> => q <Johan Lindstrom>,
    q <JOHANVDB> => q <Johan Van den Brande>,
    q <JOHND> => q <John Drago>,
    q <JOHNSCA> => q <Cory Johns>,
    q <JONALLEN> => q <Jon Allen>,
    q <JONASBN> => q <Jonas B. Nielsen>,
    q <JONATHAN> => q <Jonathan Worthington>,
    q <JOSHUA> => q <Joshua Keroes>,
    q <JOUKE> => q <Jouke Visser>,
    q <JPEACOCK> => q <John Peacock>,
    q <JPIERCE> => q <Jerrad Pierce>,
    q <JPRIT> => q <Joshua Nathaniel Pritikin>,
    q <JQUELIN> => q <Jerome Quelin>,
    q <JRED> => q <Joern Reder>,
    q <JROBINSON> => q <Jess Robinson>,
    q <JROCKWAY> => q <Jonathan Rockway>,
    q <JSHIRLEY> => q <J. Shirley>,
    q <JSIRACUSA> => q <John Siracusa>,
    q <JSMITH> => q <James G Smith>,
    q <JSTENZEL> => q <Jochen Stenzel>,
    q <JSTOWE> => q <Jonathan Stowe>,
    q <JSWARTZ> => q <Jonathan Swartz>,
    q <JTRAMMELL> => q <John J. Trammell>,
    q <JUERD> => q <Juerd Waalboer>,
    q <JV> => q <Johan Vromans>,
    q <JWALT> => q <Joerg Walter>,
    q <JWIED> => q <Jochen Wiedmann>,
    q <JZUCKER> => q <Jeff Zucker>,
    q <KAARE> => q <Kaare Rasmussen>,
    q <KAHIRSCH> => q <Ken Hirsch>,
    q <KAKADU> => q <Konstantin Kapitanov>,
    q <KAKE> => q <Kake L Pugh>,
    q <KANE> => q <Jos Boumans>,
    q <KAPPA> => q <Alex Kapranoff>,
    q <KARASIK> => q <Dmitry Karasik>,
    q <KARMAN> => q <Peter Karman>,
    q <KASEI> => q <Marty Pauley>,
    q <KAWASAKI> => q <Yusuke Kawasaki>,
    q <KAZEBURO> => q <Masahiro Nagano>,
    q <KAZUHO> => q <Kazuho Oku>,
    q <KEEDI> => q <Keedi Kim>,
    q <KEICHNER> => q <Klaus Eichner>,
    q <KENTARO> => q <Kentaro Kuribayashi>,
    q <KENTNL> => q <Kent Fredric>,
    q <KENWU> => q <lilo>,
    q <KESTEB> => q <Kevin L. Esteb>,
    q <KHAMPTON> => q <Kip Hampton>,
    q <KIMOTO> => q <Yuki Kimoto>,
    q <KIMRYAN> => q <Kim Ryan>,
    q <KIRSLE> => q <Noah Petherbridge>,
    q <KITANO> => q <dann>,
    q <KJALB> => q <Kenneth Albanowski>,
    q <KJETILK> => q <Kjetil Kjernsmo>,
    q <KMACLEOD> => q <Ken MacLeod>,
    q <KMCGRATH> => q <Kevin C. McGrath>,
    q <KMELTZ> => q <Kevin Meltzer>,
    q <KNORR> => q <Torsten Knorr>,
    q <KOKOGIKO> => q <OHTSUKA Ko-hei>,
    q <KOLIBRIE> => q <Nathan Gray>,
    q <KOTEROV> => q <Dmitry Koterov>,
    q <KRAEHE> => q <Michael Koehne>,
    q <KRYDE> => q <Kevin Ryde>,
    q <KTAT> => q <Kato Atsushi>,
    q <KTHAKORE> => q <Kartik Thakore>,
    q <KUBINA> => q <Jeff Kubina>,
    q <KULP> => q <Darren Kulp>,
    q <KURIHARA> => q <Yoshiki KURIHARA>,
    q <KVAIL> => q <Kevin Michael Vail>,
    q <KWILLIAMS> => q <Ken Williams>,
    q <KWITKNR> => q <KAWAI, Takanori>,
    q <LBROCARD> => q <Leon Brocard>,
    q <LDS> => q <Lincoln D. Stein>,
    q <LEEDO> => q <Lee Aylward>,
    q <LEIFJ> => q <Leif Johansson>,
    q <LEMBARK> => q <Steven Lembark>,
    q <LEOCHARRE> => q <Leo Charre>,
    q <LEONT> => q <Leon Timmermans>,
    q <LETO> => q <Jonathan Leto>,
    q <LGODDARD> => q <Lee Goddard>,
    q <LLAP> => q <Leo Lapworth>,
    q <LODIN> => q <Johan Lodin>,
    q <LPALMER> => q <Luke Palmer>,
    q <LUISMUNOZ> => q <Luis Munoz>,
    q <LUKEC> => q <Luke Closs>,
    q <LUSHE> => q <Masatoshi Mizuno>,
    q <LUSOL> => q <Stephen O. Lidie>,
    q <LYOKATO> => q <Lyo Kato>,
    q <MADWOLF> => q <Massimiliano Pala>,
    q <MAJENSEN> => q <Mark Allen Jensen>,
    q <MAKAMAKA> => q <Makamaka Hannyaharamitu>,
    q <MALUKU> => q <Marc - Sebastian Lucksch>,
    q <MANFREDI> => q <Leo Manfredi>,
    q <MARCEL> => q <Marcel Gruenauer == hanekomu>,
    q <MARKF> => q <Mark Fowler>,
    q <MARKOV> => q <Mark Overmeer>,
    q <MARKSTOS> => q <Mark Stosberg>,
    q <MARNANEL> => q <Thomas Thurman>,
    q <MAROS> => q <Maros Kollar>,
    q <MARTIJN> => q <Martijn van Beers>,
    q <MASAKI> => q <NAKAGAWA Masaki>,
    q <MATISSE> => q <Matisse Enzer>,
    q <MATSUMOTO> => q <syushi matsumoto>,
    q <MATTLAW> => q <Matthew Lawrence>,
    q <MAUKE> => q <Lukas Mai>,
    q <MBARBON> => q <Mattia Barbon>,
    q <MBROOKS> => q <Marc S. Brooks>,
    q <MCANTONI> => q <Matteo Cantoni>,
    q <MCEGLOWS> => q <Maciej Ceglowski>,
    q <MCMAHON> => q <Joe McMahon>,
    q <MDOM> => q <Mario Domgoergen>,
    q <MELO> => q <Pedro Melo>,
    q <MEMOWE> => q <Mirko Westermeier>,
    q <MERLYN> => q <Randal L. Schwartz>,
    q <METZZO> => q <Mark Ethan Trostler>,
    q <MGRAHAM> => q <Michael Graham>,
    q <MGRIMES> => q <Mark Grimes>,
    q <MHAMILTON> => q <Martin Hamilton>,
    q <MHOSKEN> => q <Martin Hosken>,
    q <MHX> => q <Marcus Holland-Moritz>,
    q <MICB> => q <Malcolm Beattie>,
    q <MICHAEL> => q <Michael Roberts>,
    q <MIKEDLR> => q <Michael De La Rue>,
    q <MIKEM> => q <Mike McCauley>,
    q <MIKER> => q <Michael Robinton>,
    q <MIKI> => q <Takeshi Miki>,
    q <MIKIHOSHI> => q <KAN Fushihara>,
    q <MIRK> => q <Mike Taylor>,
    q <MIROD> => q <Michel Rodriguez>,
    q <MITHALDU> => q <Christian Walde>,
    q <MIYAGAWA> => q <Tatsuhiko Miyagawa>,
    q <MIYAZAKI> => q <Ittetsu Miyazaki>,
    q <MIZZY> => q <Gosuke Miyashita>,
    q <MJCARMAN> => q <Michael Carman>,
    q <MJD> => q <Mark Jason Dominus>,
    q <MKUTTER> => q <Martin Kutter>,
    q <MLEHMANN> => q <Marc Lehmann>,
    q <MLFISHER> => q <Mark Leighton Fisher>,
    q <MNDRIX> => q <Michael Hendricks>,
    q <MNEYLON> => q <Michael K. Neylon>,
    q <MOB> => q <Marty O'Brien>,
    q <MOCK> => q <MOCK>,
    q <MOCONNOR> => q <Matthew O'Connor>,
    q <MONS> => q <Mons Anderson>,
    q <MOOLI> => q <Peter Corlett>,
    q <MORITZ> => q <Moritz Lenz>,
    q <MORIYA> => q <Moriya Masaki>,
    q <MRAMBERG> => q <Marcus Ramberg>,
    q <MRDVT> => q <Michael R. Davis>,
    q <MROGASKI> => q <Mark Rogaski>,
    q <MSCHILLI> => q <Michael Schilli>,
    q <MSCHOUT> => q <Michael Schout>,
    q <MSCHWARTZ> => q <Martin Schwartz>,
    q <MSCHWERN> => q <Michael G Schwern>,
    q <MSERGEANT> => q <MSERGEANT>,
    q <MSISK> => q <Matt Sisk>,
    q <MSOUTHERN> => q <Mark Southern>,
    q <MSTROUT> => q <Matt S Trout>,
    q <MTHURN> => q <Martin 'Kingpin' Thurn>,
    q <MTL> => q <RECRUIT Media Technology Labs>,
    q <MUENALAN> => q <Murat Uenalan>,
    q <MUIR> => q <David Muir Sharnoff>,
    q <MWS> => q <Markus Winand>,
    q <MZSANFORD> => q <Matt Sanford>,
    q <NACHBAUR> => q <Michael A. Nachbaur>,
    q <NANARDON> => q <Olivier Thauvin>,
    q <NAOYA> => q <Naoya Ito>,
    q <NATG> => q <Nathan Goodman>,
    q <NATTIS> => q <Udlei D. R. Nattis>,
    q <NCLEATON> => q <Nick Cleaton>,
    q <NEILW> => q <Neil Watkiss>,
    q <NEKOKAK> => q <Atsushi Kobayashi>,
    q <NEMUX> => q <Marco Romano>,
    q <NI-S> => q <Nick Ing-Simmons (PAUSE Custodial Account)>,
    q <NICOLAW> => q <Nicola Worthington>,
    q <NIKC> => q <Nik Clayton>,
    q <NILSONSFJ> => q <Nilson Santos Figueiredo Junior>,
    q <NITO> => q <Nito Martinez>,
    q <NJH> => q <Nicholas J Humfrey>,
    q <NKH> => q <Nadim Ibn Hamouda El Khemir>,
    q <NKUITSE> => q <Paul Hoffman>,
    q <NOBULL> => q <Brian McCauley>,
    q <NODINE> => q <Mark Nodine>,
    q <NOTBENH> => q <ben hengst>,
    q <NPEREZ> => q <Nicholas Perez>,
    q <NRG> => q <Odintsov Pavel>,
    q <NUFFIN> => q <Yuval Kogman>,
    q <NWCLARK> => q <Nicholas Clark>,
    q <NWETTERS> => q <Nigel Wetters Gourlay>,
    q <NWIGER> => q <Nate Wiger>,
    q <OALDERS> => q <Olaf Alders>,
    q <OBRADOVIC> => q <Darko Obradovic>,
    q <OESTERHOL> => q <hod>,
    q <OFEYAIKON> => q <Ofey Aikon>,
    q <OLIVER> => q <Oliver Gorwits>,
    q <OPI> => q <Torsten Foertsch>,
    q <OSFAMERON> => q <osfameron>,
    q <OVID> => q <Curtis 'Ovid' Poe>,
    q <OYAMA> => q <Hiroyuki OYAMA>,
    q <PAJAS> => q <Petr Pajas>,
    q <PARDUS> => q <Jaap Karssenberg>,
    q <PATL> => q <Patrick LeBoutillier>,
    q <PDENIS> => q <Pierre Denis>,
    q <PDONELAN> => q <Patrick Donelan>,
    q <PEPE> => q <Christoph Bussenius>,
    q <PERFSONAR> => q <Aaron Brown>,
    q <PERIGRIN> => q <Chris Prather>,
    q <PERLER> => q <Moritz Onken>,
    q <PERRAD> => q <Francois Perrad>,
    q <PETDANCE> => q <Andy Lester>,
    q <PEVANS> => q <Paul Evans>,
    q <PGOLLUCCI> => q <Philip M. Gollucci>,
    q <PHAYLON> => q <Robert 'phaylon' Sedlacek>,
    q <PHILCROW> => q <Philip Crow>,
    q <PHISH> => q <Christian Glahn>,
    q <PHRED> => q <Fred Moyer>,
    q <PIERS> => q <Piers Harding>,
    q <PIJLL> => q <Eugene van der Pijll>,
    q <PINYAN> => q <Jeff Pinyan>,
    q <PIP> => q <Pip Stuart>,
    q <PJB> => q <Peter Billam>,
    q <PJF> => q <Paul Jamieson Fenwick>,
    q <PJFL> => q <Peter Flanigan>,
    q <PKENT> => q <P Kent>,
    q <PLU> => q <Johannes Plunien>,
    q <PMAKHOLM> => q <Peter Makholm>,
    q <PMAREK> => q <Philipp Marek>,
    q <PMH> => q <Peter Haworth>,
    q <PMQS> => q <Paul Marquess>,
    q <PMURIAS> => q <Pawel Murias>,
    q <PNE> => q <Philip Newton>,
    q <PODMASTER> => q <D. H.>,
    q <POLETTIX> => q <Flavio Poletti>,
    q <POTYL> => q <Emmanuel Rodriguez>,
    q <POWERMAN> => q <Alex Efros>,
    q <PRBRENAN> => q <Philip R Brenan>,
    q <PSHANGOV> => q <Peter Shangov>,
    q <PSINNOTT> => q <Peter Sinnott>,
    q <RANI> => q <Rani Pinchuk>,
    q <RATTLER> => q <Michael Bochkaryov>,
    q <RBDAVISON> => q <R Bernard Davison>,
    q <RBERJON> => q <Robin Berjon>,
    q <RBOW> => q <Rich Bowen>,
    q <RBS> => q <Barrie Slaymaker>,
    q <RCAPUTO> => q <Rocco Caputo>,
    q <RCLAMP> => q <Richard Clamp>,
    q <RCROWDER> => q <Roy Elton Crowder, III>,
    q <REATMON> => q <Ryan Eatmon>,
    q <REDICAPS> => q <woosley.xu>,
    q <REHSACK> => q <Jens Rehsack>,
    q <RENEEB> => q <Renee Baecker>,
    q <RETOH> => q <Reto Schaer>,
    q <REVMISCHA> => q <Mischa Spiegelmock>,
    q <RFOLEY> => q <Richard Foley>,
    q <RGARCIA> => q <Rafael Garcia-Suarez>,
    q <RGARTON> => q <roderick garton>,
    q <RHANDOM> => q <Paul Seamons>,
    q <RHESA> => q <Rhesa Rozendaal>,
    q <RHUNDT> => q <Richard Hundt>,
    q <RICKM> => q <Rick Measham>,
    q <RIZEN> => q <JT Smith>,
    q <RJBS> => q <Ricardo Signes>,
    q <RJE> => q <Robert Eaglestone>,
    q <RJRAY> => q <Randy J Ray>,
    q <RKIES> => q <Robert Kiesling>,
    q <RKINYON> => q <Rob Kinyon>,
    q <RKITOVER> => q <Rafael Kitover>,
    q <RKOBES> => q <Randy Kobes>,
    q <RKRIMEN> => q <Robert Krimen>,
    q <RLZWART> => q <Raoul Zwart>,
    q <RMCFARLA> => q <Ross McFarland>,
    q <ROBERTMAY> => q <Robert May>,
    q <ROBINS> => q <Robin Smidsrod>,
    q <ROBL> => q <Rob Lee>,
    q <ROBM> => q <Rob Mueller>,
    q <ROBWALKER> => q <Robby Walker>,
    q <ROGERHALL> => q <Roger A Hall>,
    q <ROKR> => q <Robert Krimen>,
    q <ROMM> => q <Roman M. Parparov>,
    q <RONAN> => q <Ronan Oger>,
    q <ROODE> => q <Eric J. Roode>,
    q <ROOTKWOK> => q <Baggio, Kwok Lok Chung>,
    q <ROSCH> => q <Roderick Schertler>,
    q <ROSCIO> => q <Steve Roscio>,
    q <ROSULEK> => q <Mike Rosulek>,
    q <RPAGITSCH> => q <Reinhard Pagitsch>,
    q <RPETTETT> => q <Roger Pettett>,
    q <RRA> => q <Russ Allbery>,
    q <RRWO> => q <Robert Rothenberg>,
    q <RSANDBERG> => q <Reed Sandberg>,
    q <RSAVAGE> => q <Ron Savage>,
    q <RSE> => q <Ralf S. Engelschall>,
    q <RSMITH> => q <Randall Smith>,
    q <RSN> => q <Ryan Niebur>,
    q <RSOD> => q <Richard Soderberg>,
    q <RSOLIV> => q <Olivier Poitrey>,
    q <RSRCHBOY> => q <Chris Weyl>,
    q <RUBYKAT> => q <Kathryn Andersen>,
    q <RURBAN> => q <Reini Urban>,
    q <RUSAKOV> => q <Sergey Rusakov>,
    q <RUZ> => q <Ruslan U. Zakirov>,
    q <RYBSKEJ> => q <Eric Rybski>,
    q <RYOCHIN> => q <Ryo Okamoto>,
    q <SADAHIRO> => q <SADAHIRO Tomoyuki>,
    q <SALVA> => q <Salvador Fandino Garcia>,
    q <SAMTREGAR> => q <Sam Tregar>,
    q <SAMV> => q <Sam Vilain>,
    q <SANKO> => q <Sanko Robinson>,
    q <SAPER> => q <Sebastien Aperghis-Tramoni>,
    q <SARGIE> => q <Peter Sergeant>,
    q <SARTAK> => q <Shawn M Moore>,
    q <SATOH> => q <cho45 (SATOH)>,
    q <SAXJAZMAN> => q <Wes Young>,
    q <SBECK> => q <Sullivan Beck>,
    q <SBURKE> => q <Sean M. Burke>,
    q <SCHAFFTER> => q <Gustav Schaffter>,
    q <SCHROEER> => q <Daniel Schroeer>,
    q <SCHUBIGER> => q <Steven Schubiger (stsc)>,
    q <SCHWIGON> => q <Steffen Schwigon>,
    q <SCOTT> => q <Scott Penrose>,
    q <SCOTTW> => q <Scott Wiersdorf>,
    q <SDEN> => q <Spiros Denaxas>,
    q <SDERLE> => q <Schuyler Erle>,
    q <SEANO> => q <Sean O'Rourke>,
    q <SEKIMURA> => q <Masayoshi Sekimura>,
    q <SENGER> => q <Sebastian Enger>,
    q <SFINK> => q <Steve A Fink>,
    q <SGOELDNER> => q <Steffen Goeldner>,
    q <SGRAHAM> => q <Sam Graham>,
    q <SHARIFULN> => q <Anatoly Sharifulin>,
    q <SHARYANTO> => q <Steven Haryanto>,
    q <SHELLING> => q <J.W.Hsu>,
    q <SHERZODR> => q <Sherzod Ruzmetov>,
    q <SHEVEK> => q <Shevek>,
    q <SHLOMIF> => q <Shlomi Fish>,
    q <SIFUKURT> => q <Kurt Kincaid>,
    q <SIMON> => q <Simon Cozens>,
    q <SIMONFLK> => q <Simon Flack>,
    q <SIMONW> => q <Simon Wistow>,
    q <SISYPHUS> => q <Sisyphus>,
    q <SIZUR> => q <Eugene Grigoriev>,
    q <SJQUINNEY> => q <Stephen Quinney>,
    q <SKUD> => q <Kirrily 'Skud' Robert>,
    q <SLANNING> => q <Scott Lanning>,
    q <SMPETERS> => q <Steve Peters>,
    q <SMUELLER> => q <Steffen Mueller>,
    q <SMYLERS> => q <Smylers>,
    q <SNOWFLY> => q <Piao Ran Si Xue>,
    q <SNOWHARE> => q <Benjamin Franz>,
    q <SOCK> => q <Nicholas Gerakines>,
    q <SOFTDIA> => q <Samson Monaco Tutankhamen>,
    q <SPADKINS> => q <Stephen Adkins>,
    q <SPEEVES> => q <Shannon Eric Peevey>,
    q <SPROUT> => q <Father Chrysostomos>,
    q <SPURKIS> => q <Steve Purkis>,
    q <SREZIC> => q <Slaven Rezic>,
    q <SRSHAH> => q <Sagar R. Shah>,
    q <SSCHNEID> => q <Scott Schneider>,
    q <SSCOTTO> => q <Salvatore E. ScottoDiLuzio>,
    q <STAS> => q <Stas Bekman>,
    q <STBEY> => q <Steffen Beyer>,
    q <STEFFENW> => q <Steffen Winkler>,
    q <STEPHANB> => q <Stephan Buys>,
    q <STEPHEN> => q <Stephen Nelson>,
    q <STEVAN> => q <Stevan Little>,
    q <STEVEGT> => q <Steve Traugott>,
    q <STRO> => q <Serguei Trouchelle>,
    q <STRYTOAST> => q <Stray Taoist>,
    q <STRZELEC> => q <Strzelecki Lukasz>,
    q <SUKRIA> => q <Alexis Sukrieh>,
    q <SULLR> => q <Steffen Ullrich>,
    q <SUMMER> => q <Mark Summerfield>,
    q <SUNCPAN> => q <Sun CPAN Module Support>,
    q <SUNGO> => q <sungo>,
    q <SUNNAVY> => q <sunnavy>,
    q <SWALTERS> => q <Scott Walters>,
    q <SWMCD> => q <Steven McDougall>,
    q <SZABGAB> => q <Gabor Szabo>,
    q <TAIY> => q <Taisuke Yamada>,
    q <TAKERU> => q <Takeru INOUE>,
    q <TAMASHIRO> => q <Yuji Tamashiro>,
    q <TANIGUCHI> => q <Koichi Taniguchi>,
    q <TANIMOTO> => q <Satoshi Tanimoto>,
    q <TAYERS> => q <Tim Ayers>,
    q <TBONE> => q <Terrence Brannon>,
    q <TBR> => q <Thiago Berlitz Rondon>,
    q <TCAINE> => q <Todd Caine>,
    q <TEEJAY> => q <Aaron James Trevena>,
    q <TELS> => q <Tels>,
    q <TEODOR> => q <Teodor Zlatanov>,
    q <TEVERETT> => q <Toby Ovod-Everett>,
    q <TFOUCART> => q <Timothee Foucart>,
    q <THALJEF> => q <Jeffrey Ryan Thalhammer>,
    q <THECRAMPS> => q <X Cramps>,
    q <THHAMON> => q <Thierry Hamon>,
    q <THOSPEL> => q <Ton Hospel>,
    q <TILLY> => q <Ben Tilly>,
    q <TIMA> => q <Timothy Appnel>,
    q <TIMB> => q <Tim Bunce>,
    q <TIMBRODY> => q <Tim Brody>,
    q <TINITA> => q <Tina Muller>,
    q <TJC> => q <Toby Corkindale>,
    q <TJENNESS> => q <Tim Jenness>,
    q <TJMATHER> => q <T.J. Mather>,
    q <TKEEFER> => q <Tim Keefer>,
    q <TLBDK> => q <Troels Liebe Bentsen>,
    q <TLINDEN> => q <T. Linden>,
    q <TMTM> => q <Tony Bowden>,
    q <TMURRAY> => q <Timm Murray>,
    q <TNGUYEN> => q <Tan D Nguyen>,
    q <TOBYINK> => q <Toby Inkster>,
    q <TOKUHIROM> => q <Tokuhiro Matsuno>,
    q <TOMITA> => q <Naoki Tomita (tomi-ru)>,
    q <TOMYHERO> => q <Tomohiro Teranishi>,
    q <TONVOON> => q <Ton Voon>,
    q <TONYC> => q <Tony Cook>,
    q <TPABA> => q <Daniel Podolsky>,
    q <TPEDERSE> => q <Ted Pedersen>,
    q <TPG> => q <Toni Prug>,
    q <TRIDDLE> => q <Tyler Riddle>,
    q <TSCH> => q <Torsten Schoenfeld>,
    q <TSIBLEY> => q <Thomas Sibley>,
    q <TSKIRVIN> => q <Tim Skirvin>,
    q <TURNERJW> => q <Jim Turner>,
    q <TURUGINA> => q <KATOU Akira>,
    q <TYEMQ> => q <Tye McQueen>,
    q <TYPESTER> => q <Daisuke Murase>,
    q <ULPFR> => q <Ulrich Pfeifer>,
    q <UNRTST> => q <Joshua I. Miller>,
    q <URI> => q <Uri Guttman>,
    q <UVOELKER> => q <Uwe Voelker>,
    q <VANAMBURG> => q <Gordon Van Amburg>,
    q <VBAR> => q <Vaclav Barta>,
    q <VIPUL> => q <Vipul Ved Prakash>,
    q <VKHERA> => q <Vivek Khera>,
    q <VMORAL> => q <Victor Moral>,
    q <VPARSEVAL> => q <Tassilo von Parseval>,
    q <VPIT> => q <Vincent Pit>,
    q <VTI> => q <Viacheslav Tykhanovskyi>,
    q <VVELOX> => q <Zane C. Bowers>,
    q <VVU> => q <Alex White>,
    q <WAZZUTEKE> => q <Trevor Hall>,
    q <WILSOND> => q <Dusty Wilson>,
    q <WIMV> => q <Wim Verhaegen>,
    q <WONKO> => q <Michael Peters>,
    q <WROSS> => q <William Ross>,
    q <WSNYDER> => q <Wilson Snyder>,
    q <WYANT> => q <Tom Wyant>,
    q <XANTUS> => q <David Davis>,
    q <XERN> => q <Yung-chung Lin>,
    q <XMATH> => q <Matthijs van Duin>,
    q <XPIX> => q <Frank Herrmann>,
    q <XSAWYERX> => q <Sawyer X>,
    q <YANICK> => q <Yanick Champoux>,
    q <YANNK> => q <Yann Kerherve>,
    q <YAPPO> => q <Kazuhiro Osawa>,
    q <YOSHIDA> => q <YOSHIDA Hironori>,
    q <YUSUKEBE> => q <Yusuke Wada>,
    q <YVES> => q <Yves>,
    q <YVESAGO> => q <Yves Agostini>,
    q <ZAG> => q <Zahatski Aliaksandr>,
    q <ZAPHAR> => q <Jeremy Wall>,
    q <ZARQUON> => q <Kieren Diment>,
    q <ZEFRAM> => q <Andrew Main (Zefram)>,
    q <ZIGOROU> => q <Toru Yamaguchi>,
    q <ZOCCAV> => q <Vincenzo Zocca>,
    q <ZOFFIX> => q <Zoffix Znet>,
    q <ZOOLEIKA> => q <Jo Walsh>,
);

1;

__END__

=head1 NAME

Acme::CPANAuthors::CPANTS::FiveOrMore - CPAN Authors with five or more dists

=head1 SYNOPSIS

 use Acme::CPANAuthors;

 my $authors  = Acme::CPANAuthors -> new ("CPANTS::FiveOrMore");

 my $number   = $authors -> count;
 my @ids      = $authors -> id;
 my @distros  = $authors -> distributions ("ABIGAIL");
 my $url      = $authors -> avatar_url    ("ABIGAIL");
 my $kwalitee = $authors -> kwalitee      ("ABIGAIL");
 my $name     = $authors -> name          ("ABIGAIL");

See documentation for Acme::CPANAuthors for more details.

=head1 DESCRIPTION

This class provides a hash of PAUSE IDs and names of CPAN authors
who have five or more distributions in the CPANTS database.

=head1 DEVELOPMENT

The current sources of this module are found on github,
L<< git://github.com/Abigail/Acme--CPANAuthors--CPANTS--FiveOrMore.git >>.

=head1 AUTHOR

Abigail, L<< mailto:cpan@abigail.be >>.

=head1 COPYRIGHT and LICENSE

Copyright (C) 2009 by Abigail.

Permission is hereby granted, free of charge, to any person obtaining a
copy of this software and associated documentation files (the "Software"),   
to deal in the Software without restriction, including without limitation
the rights to use, copy, modify, merge, publish, distribute, sublicense,
and/or sell copies of the Software, and to permit persons to whom the
Software is furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included
in all copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
THE AUTHOR BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT
OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
THE SOFTWARE.

=head1 INSTALLATION

To install this module, run, after unpacking the tar-ball, the 
following commands:

   perl Makefile.PL
   make
   make test
   make install

=cut
